@@ -30,13 +30,13 @@
 #include <KHTMLPart>
 
 #include <KLocalizedString>
-#include <KToolInvocation>
 #include <KIO/Job>
+#include <QDesktopServices>
 #include <QIcon>
 #include <QStandardPaths>
 
-InfoBrowser::InfoBrowser(WorldModel* worldModel, QWidget* parent, Qt::WindowFlags flags)
-    : QDockWidget(i18n("Context info"), parent, flags),
+InfoBrowser::InfoBrowser(WorldModel* worldModel, QWidget* parent)
+    : QDockWidget(i18n("Context info"), parent),
       _worldModel(worldModel), _wikiJob(NULL), _wikiFromHistory(false), _selectionChanged(false)
 {
     QWidget* widget = new QWidget(this);
@@ -80,11 +80,11 @@ InfoBrowser::InfoBrowser(WorldModel* worldModel, QWidget* parent, Qt::WindowFlag
     _htmlPart->setDNDEnabled(false);
 
     connect(_htmlPart->browserExtension(),
-	    SIGNAL(openUrlRequest(const QUrl&, const KParts::OpenUrlArguments&, const KParts::BrowserArguments&)),
-	    this, SLOT(openUrl(const QUrl&)));
+	    SIGNAL(openUrlRequest(QUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)),
+	    this, SLOT(openUrl(QUrl)));
 
-    connect(_worldModel->selectionModel(), SIGNAL(currentChanged(const QModelIndex&, const QModelIndex&)),
-                                           this, SLOT(worldCurrentChanged(const QModelIndex&, const QModelIndex&)));
+    connect(_worldModel->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
+                                           this, SLOT(worldCurrentChanged(QModelIndex,QModelIndex)));
 
     syncSelection();
 }
@@ -112,8 +112,9 @@ void InfoBrowser::worldCurrentChanged(const QModelIndex& /*current*/, const QMod
 void InfoBrowser::syncSelection(bool checked)
 {
     if(checked) {
-        QModelIndex current = _worldModel->selectionModel()->currentIndex();
-        openUrl(QString("objinfo:").append(current.data(WorldModel::ClassNameRole).toString()), true);
+        const QModelIndex current = _worldModel->selectionModel()->currentIndex();
+        const QUrl url(QString("objinfo:").append(current.data(WorldModel::ClassNameRole).toString()));
+        openUrl(url, true);
     }
 }
 
@@ -209,9 +210,9 @@ void InfoBrowser::openUrl(const QUrl& url, bool clearHistory, bool fromHistory)
             _wikiUrl = url;
             _wikiFromHistory = fromHistory;
             _wikiJob = KIO::storedGet(url, KIO::NoReload, KIO::HideProgressInfo);
-            connect(_wikiJob, SIGNAL(result(KJob*)), this, SLOT( wikiResult(KJob*)));
+            connect(_wikiJob, SIGNAL(result(KJob*)), this, SLOT(wikiResult(KJob*)));
         } else {
-            KToolInvocation::invokeBrowser(url.url());
+            QDesktopServices::openUrl(url);
         }
     }
 
@@ -255,7 +256,7 @@ void InfoBrowser::back()
         _forwardAction->setEnabled(true);
     }
 
-    openUrl(url, false, true);
+    openUrl(QUrl(url), false, true);
 }
 
 void InfoBrowser::forward()
@@ -272,13 +273,13 @@ void InfoBrowser::forward()
         _backAction->setEnabled(true);
     }
 
-    openUrl(url, false, true);
+    openUrl(QUrl(url), false, true);
 }
 
 void InfoBrowser::openInBrowser()
 {
     if(_htmlPart->url().scheme() == "http") {
-        KToolInvocation::invokeBrowser(_htmlPart->url().url());
+        QDesktopServices::openUrl(_htmlPart->url());
     }
 }
 
